package expertiseFinderPrototype.expertiseExtraction;

import ExpertiseFinder.*;
import expertiseFinderPrototype.globals.GlobalValues;
import org.apache.lucene.index.IndexWriter;
import org.apache.lucene.analysis.standard.StandardAnalyzer;
import org.apache.lucene.analysis.StopAnalyzer;
import org.apache.lucene.analysis.SimpleAnalyzer;
import org.apache.lucene.document.Document;
import org.apache.lucene.document.Field;
import java.util.Date;
import java.io.File;
import java.io.IOException;
import java.io.FileReader;

/**
 * This class indexes the txt files parsed from the K2000 word documents. It uses
 * an IndexWriter object to perform the actual indexing and writes the index to 
 * disk. The StandardAnalyzer object performs the preprocessing. This analyzer is adapted
 * to a norwegian stopword filter and a norwegian stemmer.
 *
 * @author Audun Vennesland
 */
public class DocumentIndexer {
    
    //The actual indexing method. It uses the private methods indexDirectory 
    //and indexFile
    public static void index(File indexDir, File dataDir) throws IOException {
       
        if (!dataDir.exists() || !dataDir.isDirectory()) {
            throw new IOException(dataDir + " does not exist or is not a directory");
        }
        IndexWriter writer = new IndexWriter(indexDir, new StandardAnalyzer(), true);
        indexDirectory(writer, dataDir);
        writer.close();
    }
    //indexes a directory
    private static void indexDirectory(IndexWriter writer, File dir) throws IOException {
        //fetches all files in directory
        File[] files = dir.listFiles();
        
        //indexes files ending with .txt
        for (int i=0; i < files.length; i++) {
            File f = files[i];
            if (f.isDirectory()) {
                indexDirectory(writer, f);  // recurse
            } else if (f.getName().endsWith(".txt")) {
                indexFile(writer, f);
            }
        }
    }
    //indexes a file
    private static void indexFile(IndexWriter writer, File f) throws IOException {

        Document doc = new Document();
        doc.add(new Field(GlobalValues.contentFieldName, new FileReader(f)));
        doc.add(Field.Keyword(GlobalValues.fileNameFieldName, f.getCanonicalPath()));
        writer.addDocument(doc);
    }

    public static void main(String[] args) throws Exception {
     
        String indexFolder = GlobalValues.indexDir;
        String dataFolder = GlobalValues.dataDir;
        File indexDir = new File(indexFolder);
        File dataDir = new File(dataFolder);
        Date start = new Date();
        index(indexDir, dataDir);
        Date end = new Date();
        System.out.println("\nThe indexing stage took " + (end.getTime() - start.getTime()) + " ms");
    }

}