package expertiseFinderPrototype.expertiseMatching;

import ExpertiseFinder.*;
import expertiseFinderPrototype.expertiseModelling.Database;
import expertiseFinderPrototype.expertiseModelling.DocumentSearcher;
import expertiseFinderPrototype.expertiseModelling.Employee;
import expertiseFinderPrototype.expertiseModelling.TextProcessor;
import expertiseFinderPrototype.globals.GlobalValues;
import java.io.File;
import java.util.Date;
import java.util.*;
import org.apache.lucene.analysis.standard.StandardAnalyzer;
import org.apache.lucene.document.Document;
import org.apache.lucene.queryParser.QueryParser;
import org.apache.lucene.search.Hits;
import org.apache.lucene.search.IndexSearcher;
import org.apache.lucene.search.Query;
import org.apache.lucene.store.Directory;
import org.apache.lucene.store.FSDirectory;

/**
 *
 * @author Audun Vennesland
 */

public class ExpertiseSearcher {

public static TreeSet timeOfServiceSearch(File indexDir, String[] employeeList) throws Exception {
Directory fsDir = FSDirectory.getDirectory(indexDir,false);
IndexSearcher is = new IndexSearcher(fsDir);
Database db = new Database();
DocumentSearcher ds = new DocumentSearcher();
File cacheDir = new File(GlobalValues.cache_index);
TextProcessor tp = new TextProcessor();

TreeMap tm = new TreeMap();
//array containing the actual numYears
int[] numYearsEmployed = new int[employeeList.length];
Employee[] employee = new Employee[employeeList.length];
Integer numYears;

int numHits = 0;
for (int i = 0; i < employeeList.length; i++) {//use all employees as query
Query queryObject = QueryParser.parse("\"" + employeeList[i] + "\"",GlobalValues.contentFieldName, new StandardAnalyzer());
Hits hits = is.search(queryObject);
numHits = hits.length();

//if this employee found in the relevant documents, add the employee and the 
//number of documents he is mentioned in to the treeMap
if (hits.length() > 0) {
        db.connect(GlobalValues.db_username, GlobalValues.db_password);
	ArrayList emplList = db.returnEmployees();
        employee[i] = (Employee) emplList.get(i);
        numYearsEmployed[i] = tp.numYearsEmployed(employee[i].getEmploymentDate());
        tm.put(employeeList[i], numYears = new Integer(numYearsEmployed[i]));
	}

hits = is.search(queryObject);
}
//use TreeSet to be able to sort by value (employment time)
TreeSet ts = new TreeSet(new Comparator() {
	public int compare(Object obj, Object obj1) {
            int vcomp = ((Comparable) ((Map.Entry) obj1).getValue()).compareTo(((Map.Entry)obj).getValue());
            if (vcomp != 0) return vcomp;
            else return ((Comparable) ((Map.Entry) obj1).getKey()).compareTo(((Map.Entry) 
                obj).getKey());
	}
});

ts.addAll(tm.entrySet());
int ts_lengde = ts.size();
System.out.println("\n\nThis search resulted in " + ts_lengde + " hits: ");
int rankNumber = 0;
for (Iterator i = ts.iterator(); i.hasNext();) {

	Map.Entry entry = (Map.Entry) i.next();
        rankNumber++;
        System.out.println("\n" + rankNumber + ". " + entry.getKey() + " has " + entry.getValue() + " document(s) about this topic.\n");
	String name = (String)entry.getKey();
        String searchName = "\"" + name + "\"";
        System.out.println("Relevant documents:");
        //collects references to the documents the employee is mentioned in
        ds.documentSearchGivenCaseHandler(cacheDir, searchName); 
        System.out.println("\n");
        db.connect(GlobalValues.db_username, GlobalValues.db_password);
	//collects contact information
        db.getContactinfo(name);
        
}
return ts;
}
    
public static TreeSet search(File indexDir, String[] employeeList) throws Exception {
Directory fsDir = FSDirectory.getDirectory(indexDir,false);
IndexSearcher is = new IndexSearcher(fsDir);
Database db = new Database();
DocumentSearcher ds = new DocumentSearcher();
File cacheDir = new File(GlobalValues.cache_index);

TreeMap tm = new TreeMap();
int[] counter = new int[employeeList.length];
Integer occurrence;

int numHits = 0;
int teller = 0;
for (int i = 0; i < employeeList.length; i++) {//use all employees as query
Query queryObject = QueryParser.parse("\"" + employeeList[i] + "\"",GlobalValues.contentFieldName, new StandardAnalyzer());
Hits hits = is.search(queryObject);
numHits = hits.length();

//adds all employees whose names occur more than once to the treeMap
if (hits.length() > 0) {
	counter[i] = hits.length();
	tm.put(employeeList[i],occurrence = new Integer(counter[i]));
        }
hits = is.search(queryObject);
}
//use TreeSet to be able to sort by value (name occurrences)
TreeSet ts = new TreeSet(new Comparator() {
	public int compare(Object obj, Object obj1) {
            int vcomp = ((Comparable) ((Map.Entry) obj1).getValue()).compareTo(((Map.Entry)obj).getValue());
            if (vcomp != 0) return vcomp;
            else return ((Comparable) ((Map.Entry) obj1).getKey()).compareTo(((Map.Entry) 
                obj).getKey());
	}
});

ts.addAll(tm.entrySet());
int ts_lengde = ts.size();
System.out.println("\n\nThe query " + GlobalValues.searchFrase + " resulted in " + ts_lengde + " hits: ");
int rankNumber = 0;
for (Iterator i = ts.iterator(); i.hasNext();) {

	Map.Entry entry = (Map.Entry) i.next();
        rankNumber++;
        System.out.println("\n" + rankNumber + "." + entry.getKey() + " has " + 
        entry.getValue() + " document(s) about this subject.\n");
	String name = (String)entry.getKey();
        String searchName = "\"" + name + "\"";
        System.out.println("Relevant documents:");
        ds.documentSearchGivenCaseHandler(cacheDir, searchName);
        System.out.println("\n");
        db.connect(GlobalValues.db_username, GlobalValues.db_password);
        //collects contactinformation
	db.getContactinfo(name);
        
}
return ts;
}

}