package expertiseFinderPrototype.expertiseModelling;

import ExpertiseFinder.*;
import expertiseFinderPrototype.globals.GlobalValues;
import java.io.File;
import java.util.Date;
import org.apache.lucene.analysis.standard.StandardAnalyzer;
import org.apache.lucene.document.Document;
import org.apache.lucene.queryParser.QueryParser;
import org.apache.lucene.search.Hits;
import org.apache.lucene.search.IndexSearcher;
import org.apache.lucene.search.Query;
import org.apache.lucene.store.Directory;
import org.apache.lucene.store.FSDirectory;

/**
 * This class searches for relevant documents given a user query. It also contain
 * a method that searches for documents mentioning a given employee. These 
 * documents are presented to the expertise seeker as references to validate
 * the experts previous experience.
 * 
 * @author Audun Vennesland
 */
public class DocumentSearcher {
    
        //This method searches an index given a query. The relevant documents are
        //returned as Hits objects. An array of Strings representing the filenames
        //of the relevant documents is returned from the method.
       public static String[] search(File indexDir, String query) throws Exception {
        Directory fsDir = FSDirectory.getDirectory(indexDir,false);
        IndexSearcher is = new IndexSearcher(fsDir);
        
        Query queryObject = QueryParser.parse(query, GlobalValues.contentFieldName, new StandardAnalyzer());
        
        Hits hits = is.search(queryObject);
        
        String[] files = new String[hits.length()];
        for (int i = 0; i < hits.length(); i++) {
            Document doc = hits.doc(i);
            //puts the returned files in an array
            files[i] = doc.get(GlobalValues.fileNameFieldName);
        }
        return files;
    }
//Returns documents where a case handler is mentioned. This method is used to
//present evidence of expertise when the results are presented to the expertise
//seeker 
public static String[] documentSearchGivenCaseHandler(File indexDir, 
            String query) throws Exception {
Directory fsDir = FSDirectory.getDirectory(indexDir,false);
IndexSearcher is = new IndexSearcher(fsDir);

Query queryObject = QueryParser.parse(query,GlobalValues.contentFieldName, 
        new StandardAnalyzer());

Hits hits = is.search(queryObject);

String[] files = new String[hits.length()];
for (int i = 0; i < hits.length(); i++) {
    Document doc = hits.doc(i);
    //Puts returned files in an array
    files[i] = doc.get(GlobalValues.fileNameFieldName);
    System.out.println(files[i]);
}
return files;
}
    
}