package expertiseFinderPrototype.expertiseModelling;

/**
 * This class is used to index the subset of documents found relevant in the document 
 * search (these documents are cached and placed in a folder). This class does not
 * utilize a main method as it is executed in the ExpertiseFinder class.
 *
 * @author Audun Vennesland
 */
import ExpertiseFinder.*;
import expertiseFinderPrototype.globals.GlobalValues;
import org.apache.lucene.index.IndexWriter;
import org.apache.lucene.analysis.standard.StandardAnalyzer;
import org.apache.lucene.document.Document;
import org.apache.lucene.document.Field;

import java.io.File;
import java.io.IOException;
import java.io.FileReader;

public class ExpertiseIndexer {
    public static void index(File indexDir, File dataDir) throws IOException {
        if (!dataDir.exists() || !dataDir.isDirectory()) {
            throw new IOException(dataDir + " does not exist or is not a directory");
        }
        IndexWriter writer = new IndexWriter(indexDir, new StandardAnalyzer(), true);
        indexDirectory(writer, dataDir);
        writer.close();
    }
    
    private static void indexDirectory(IndexWriter writer, File dir) throws IOException {
        File[] files = dir.listFiles();
        
        for (int i=0; i < files.length; i++) {
            File f = files[i];
            if (f.isDirectory()) {
                indexDirectory(writer, f);  // recurse
            } else if (f.getName().endsWith(".txt")) {
                indexFile(writer, f);
            }
        }
    }
    
    private static void indexFile(IndexWriter writer, File f) throws IOException {
        Document doc = new Document();
        doc.add(new Field(GlobalValues.contentFieldName, new FileReader(f)));
        doc.add(Field.Keyword(GlobalValues.fileNameFieldName, f.getCanonicalPath()));
        writer.addDocument(doc);
    }
}