package expertiseFinderPrototype.expertiseModelling;

import ExpertiseFinder.*;
import expertiseFinderPrototype.globals.GlobalValues;
import java.util.*;
import java.io.*;

/**
 * This class is the "slave class". It uses mainly string methods as 
 * work-a-rounds to some text issues, mainly issues between how text is 
 * stored in the database and how it is presented in the K2000 documents
 *
 * @author Audun Vennesland
 */
public class TextProcessor {

/** copies a file from one location and adds it in a new folder */
public void copyFile(String in, String out) throws Exception {
    FileInputStream fis  = new FileInputStream(in);
    FileOutputStream fos = new FileOutputStream(out);
    byte[] buf = new byte[1024];
    int i = 0;
    while((i=fis.read(buf))!=-1) {
      fos.write(buf, 0, i);
      }
    fis.close();
    fos.close();
    }



//converts all letter to lowercase
public String turnSmall(String name) {
    return name.toLowerCase();
}

//returns correct ordering of names
public String returnCorrectNameOrder(String name) {
    StringTokenizer st = new StringTokenizer(name);
    int countNames = st.countTokens();
    
    if(countNames == 2) {
        int numDigits = name.length();
        int space = name.indexOf(" ");
        String lastname = name.substring(space+1, numDigits);
        String firstname = name.substring(0, space);
        name = lastname + " " + firstname;
    }
    else if (countNames == 3) {
        int numDigits = name.length();
        int space = name.indexOf(" ");
        
        while (st.hasMoreTokens()) {
            String lastname = st.nextToken();
            String firstname = st.nextToken();
            String middlename = st.nextToken();
            name = firstname + " " + middlename + " " + lastname;
        }
    }
    return name;
}

//returns reverse ordering of names to fit database structure
public String returnReverseNameOrder(String name) {
    StringTokenizer st = new StringTokenizer(name);
    int countNames = st.countTokens();

    if(countNames == 2) {
        int numDigits = name.length();
        int space = name.indexOf(" ");
        String lastname = name.substring(space+1, numDigits);
        String firstname = name.substring(0, space);
        name = lastname + " " + firstname;
    }
    else if (countNames == 3) {
        int numDigits = name.length();
        int space = name.indexOf(" ");

        while (st.hasMoreTokens()) {
            String firstname = st.nextToken();
            String middlename = st.nextToken();
            String lastname = st.nextToken();
            name = lastname + " " + firstname + " " + middlename;
        }
    }
    return name;
}


//calculates the number of years the employee has been employed 
//(used in the presentation)
public String employmentTime(String db_date) {
    int numDigits = db_date.length();
    int line = db_date.indexOf("-");
    Integer year = new Integer(db_date.substring(0, line));
    Integer month = new Integer(db_date.substring(line+1,7));
    Integer day = new Integer(db_date.substring(8, numDigits));
    GregorianCalendar GCdate = new GregorianCalendar(year, month, day);
    Date todaysDate = new Date();
    long todDate = todaysDate.getTime();
    Date employedDate = GCdate.getTime();
    long emplDate = employedDate.getTime();
    long msDiff = todDate-emplDate;
    long secDiff = msDiff/1000;
    int yearDiff = (int)secDiff/31449600;
    secDiff = secDiff-(yearDiff*31449600);
    int remainingMonths = (int)secDiff/2620800;
    return yearDiff + " years and " + remainingMonths + " months";
}

//calculates how many years the employee has been employed in his current position
//(used in the modelling)
public int numYearsEmployed(String db_date) {
    int numDigits = db_date.length();
    int line = db_date.indexOf("-");
    Integer year = new Integer(db_date.substring(0, line));
    Integer month = new Integer(db_date.substring(line+1,7));
    Integer day = new Integer(db_date.substring(8, numDigits));
    GregorianCalendar GCdate = new GregorianCalendar(year, month, day);
    Date todaysDate = new Date();
    long todDate = todaysDate.getTime();
    Date employedDate = GCdate.getTime();
    long emplDate = employedDate.getTime();
    long msDiff = todDate-emplDate;
    long secDiff = msDiff/1000;
    int yearDiff = (int)secDiff/31449600;
    return yearDiff;
}

//collects tokens, adds whitespace and converts to lowercase 
public void makeSearchFriendly(File in, File out) throws Exception {
	FileReader fr = new FileReader(in);
	BufferedReader br = new BufferedReader(fr);
	StringBuffer sb = new StringBuffer();
	FileWriter fw = new FileWriter(out);
	PrintWriter pw = new PrintWriter(new BufferedWriter(fw));
	String line = br.readLine();
	while (line != null) {
		StringTokenizer st = new StringTokenizer(line,
                        GlobalValues.seperators);
		while (st.hasMoreTokens()) {
			String s = turnSmall(st.nextToken());
			sb.append(s + " "); 

		}
		line = br.readLine();
		}
		pw.print(sb);
		br.close();
		pw.close();
}

}
