package expertiseFinderPrototype.expertisePresentation;

import ExpertiseFinder.*;
import expertiseFinderPrototype.expertiseMatching.ExpertiseSearcher;
import expertiseFinderPrototype.expertiseModelling.Database;
import expertiseFinderPrototype.expertiseModelling.DocumentSearcher;
import expertiseFinderPrototype.expertiseModelling.Employee;
import expertiseFinderPrototype.expertiseModelling.ExpertiseIndexer;
import expertiseFinderPrototype.expertiseModelling.TextProcessor;
import expertiseFinderPrototype.globals.GlobalValues;
import java.util.*;
import java.util.Date;
import java.sql.*;
import java.io.*;

/**
 * This class runs the Expertise finder application. 
 *
 * @author Audun Vennesland
 */
public class ExpertiseFinder {
    
    public static void main(String[] args) throws Exception {
        
        Database db = new Database();
        ArrayList employeeList = new ArrayList();
        DocumentSearcher documentSearcher = new DocumentSearcher();
        File indexDir = new File(GlobalValues.indexDir);
        File dataDir = new File(GlobalValues.dataDir);
        File cache_index = new File(GlobalValues.cache_index);
        File cache = new File(GlobalValues.cache);
        File preCache = new File(GlobalValues.precache);
        ExpertiseSearcher expertiseSearcher = new ExpertiseSearcher();
        HtmlSearcher htmlSearcher = new HtmlSearcher();
        
        //timetaking
        Date start = new Date();

        /** Employee handling */
               
        //connects to database
        db.connect(GlobalValues.db_username, GlobalValues.db_password);
        employeeList = db.returnEmployees();
        //creates array for employee objects
        Employee[] employee = new Employee[employeeList.size()];
               
        //populates the array with names found in the employee objects gathered 
        //from the database
        String[] nameArray = new String[employeeList.size()];
        for (int i = 0; i < employeeList.size(); i++) {
            employee[i] = (Employee)employeeList.get(i);
            nameArray[i] = employee[i].getName();
        
        }
        
         /** Document handling */
            
        //gathers the relevant documents from the search engine
        String[] relevantDocs = documentSearcher.search(indexDir, 
                GlobalValues.searchFrase);
        String targetFile = "";
        
        //caches the relevant documents in a precache folder on disk.
        TextProcessor tb = new TextProcessor();
        for (int i = 0; i < relevantDocs.length; i++) {
            targetFile = GlobalValues.precache + "\\" + (i+1) + ".txt";
            tb.copyFile(relevantDocs[i], targetFile);
        }
                
        File[] preCacheFiles = preCache.listFiles();
                
        for (int i = 0; i < preCacheFiles.length; i++) {
            String cacheFiles = GlobalValues.cache + "\\" + (i + 1) + ".txt";
            File f = new File(cacheFiles);
            
            //processes the precached files and moves them to the final
            //cache folder
            tb.makeSearchFriendly(preCacheFiles[i],f);
        }
        
        /** Indexing stage */
            
        System.out.println("Indexing relevant documents...");
        ExpertiseIndexer ei = new ExpertiseIndexer();
        ei.index(cache_index,cache);
       
        /** The actual expertise finding and presentation */
        
        //find all case handlers in the relevant docs
        TreeSet relevantExperts = expertiseSearcher.search(cache_index, nameArray);
        
        //timetaking
        Date end = new Date();
        System.out.println("\nThe expertise finding took " + (end.getTime() - start.getTime()) + " ms");
        
        }
}



